# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/daml_lf_dev/daml_lf.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import daml_lf_1_pb2 as com_dot_daml_dot_daml__lf__dev_dot_daml__lf__1__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/daml_lf_dev/daml_lf.proto",
    package="daml_lf_dev",
    syntax="proto3",
    serialized_options=b"\n\024com.daml.daml_lf_dev\252\002\033Com.Daml.Daml_Lf_Dev.DamlLf",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n"com/daml/daml_lf_dev/daml_lf.proto\x12\x0b\x64\x61ml_lf_dev\x1a$com/daml/daml_lf_dev/daml_lf_1.proto"]\n\x0e\x41rchivePayload\x12\r\n\x05minor\x18\x03 \x01(\t\x12\'\n\tdaml_lf_1\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.PackageH\x00\x42\x05\n\x03SumJ\x06\x08\x8fN\x10\x90NJ\x04\x08\x01\x10\x02"Z\n\x07\x41rchive\x12\x30\n\rhash_function\x18\x01 \x01(\x0e\x32\x19.daml_lf_dev.HashFunction\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x0c\n\x04hash\x18\x04 \x01(\t*\x1a\n\x0cHashFunction\x12\n\n\x06SHA256\x10\x00\x42\x34\n\x14\x63om.daml.daml_lf_dev\xaa\x02\x1b\x43om.Daml.Daml_Lf_Dev.DamlLfb\x06proto3',
    dependencies=[
        com_dot_daml_dot_daml__lf__dev_dot_daml__lf__1__pb2.DESCRIPTOR,
    ],
)

_HASHFUNCTION = _descriptor.EnumDescriptor(
    name="HashFunction",
    full_name="daml_lf_dev.HashFunction",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SHA256",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=276,
    serialized_end=302,
)
_sym_db.RegisterEnumDescriptor(_HASHFUNCTION)

HashFunction = enum_type_wrapper.EnumTypeWrapper(_HASHFUNCTION)
SHA256 = 0


_ARCHIVEPAYLOAD = _descriptor.Descriptor(
    name="ArchivePayload",
    full_name="daml_lf_dev.ArchivePayload",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="minor",
            full_name="daml_lf_dev.ArchivePayload.minor",
            index=0,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="daml_lf_1",
            full_name="daml_lf_dev.ArchivePayload.daml_lf_1",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="Sum",
            full_name="daml_lf_dev.ArchivePayload.Sum",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=89,
    serialized_end=182,
)


_ARCHIVE = _descriptor.Descriptor(
    name="Archive",
    full_name="daml_lf_dev.Archive",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="hash_function",
            full_name="daml_lf_dev.Archive.hash_function",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="daml_lf_dev.Archive.payload",
            index=1,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="hash",
            full_name="daml_lf_dev.Archive.hash",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=184,
    serialized_end=274,
)

_ARCHIVEPAYLOAD.fields_by_name[
    "daml_lf_1"
].message_type = com_dot_daml_dot_daml__lf__dev_dot_daml__lf__1__pb2._PACKAGE
_ARCHIVEPAYLOAD.oneofs_by_name["Sum"].fields.append(_ARCHIVEPAYLOAD.fields_by_name["daml_lf_1"])
_ARCHIVEPAYLOAD.fields_by_name["daml_lf_1"].containing_oneof = _ARCHIVEPAYLOAD.oneofs_by_name["Sum"]
_ARCHIVE.fields_by_name["hash_function"].enum_type = _HASHFUNCTION
DESCRIPTOR.message_types_by_name["ArchivePayload"] = _ARCHIVEPAYLOAD
DESCRIPTOR.message_types_by_name["Archive"] = _ARCHIVE
DESCRIPTOR.enum_types_by_name["HashFunction"] = _HASHFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArchivePayload = _reflection.GeneratedProtocolMessageType(
    "ArchivePayload",
    (_message.Message,),
    {
        "DESCRIPTOR": _ARCHIVEPAYLOAD,
        "__module__": "com.daml.daml_lf_dev.daml_lf_pb2"
        # @@protoc_insertion_point(class_scope:daml_lf_dev.ArchivePayload)
    },
)
_sym_db.RegisterMessage(ArchivePayload)

Archive = _reflection.GeneratedProtocolMessageType(
    "Archive",
    (_message.Message,),
    {
        "DESCRIPTOR": _ARCHIVE,
        "__module__": "com.daml.daml_lf_dev.daml_lf_pb2"
        # @@protoc_insertion_point(class_scope:daml_lf_dev.Archive)
    },
)
_sym_db.RegisterMessage(Archive)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/command_completion_service.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from . import (
    completion_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_completion__pb2,
    ledger_offset_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_ledger__offset__pb2,
    trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2,
)

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/command_completion_service.proto",
    package="com.daml.ledger.api.v1",
    syntax="proto3",
    serialized_options=b'\n\026com.daml.ledger.api.v1B"CommandCompletionServiceOuterClass\252\002\026Com.Daml.Ledger.Api.V1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n7com/daml/ledger/api/v1/command_completion_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\'com/daml/ledger/api/v1/completion.proto\x1a*com/daml/ledger/api/v1/ledger_offset.proto\x1a*com/daml/ledger/api/v1/trace_context.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x8b\x01\n\x17\x43ompletionStreamRequest\x12\x11\n\tledger_id\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\t\x12\x0f\n\x07parties\x18\x03 \x03(\t\x12\x34\n\x06offset\x18\x04 \x01(\x0b\x32$.com.daml.ledger.api.v1.LedgerOffset"\x8b\x01\n\x18\x43ompletionStreamResponse\x12\x36\n\ncheckpoint\x18\x01 \x01(\x0b\x32".com.daml.ledger.api.v1.Checkpoint\x12\x37\n\x0b\x63ompletions\x18\x02 \x03(\x0b\x32".com.daml.ledger.api.v1.Completion"s\n\nCheckpoint\x12/\n\x0brecord_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x06offset\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v1.LedgerOffset"g\n\x14\x43ompletionEndRequest\x12\x11\n\tledger_id\x18\x01 \x01(\t\x12<\n\rtrace_context\x18\xe8\x07 \x01(\x0b\x32$.com.daml.ledger.api.v1.TraceContext"M\n\x15\x43ompletionEndResponse\x12\x34\n\x06offset\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v1.LedgerOffset2\x81\x02\n\x18\x43ommandCompletionService\x12w\n\x10\x43ompletionStream\x12/.com.daml.ledger.api.v1.CompletionStreamRequest\x1a\x30.com.daml.ledger.api.v1.CompletionStreamResponse0\x01\x12l\n\rCompletionEnd\x12,.com.daml.ledger.api.v1.CompletionEndRequest\x1a-.com.daml.ledger.api.v1.CompletionEndResponseBU\n\x16\x63om.daml.ledger.api.v1B"CommandCompletionServiceOuterClass\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3',
    dependencies=[
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_completion__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_ledger__offset__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_COMPLETIONSTREAMREQUEST = _descriptor.Descriptor(
    name="CompletionStreamRequest",
    full_name="com.daml.ledger.api.v1.CompletionStreamRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ledger_id",
            full_name="com.daml.ledger.api.v1.CompletionStreamRequest.ledger_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="application_id",
            full_name="com.daml.ledger.api.v1.CompletionStreamRequest.application_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parties",
            full_name="com.daml.ledger.api.v1.CompletionStreamRequest.parties",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="com.daml.ledger.api.v1.CompletionStreamRequest.offset",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=246,
    serialized_end=385,
)


_COMPLETIONSTREAMRESPONSE = _descriptor.Descriptor(
    name="CompletionStreamResponse",
    full_name="com.daml.ledger.api.v1.CompletionStreamResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="checkpoint",
            full_name="com.daml.ledger.api.v1.CompletionStreamResponse.checkpoint",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="completions",
            full_name="com.daml.ledger.api.v1.CompletionStreamResponse.completions",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=388,
    serialized_end=527,
)


_CHECKPOINT = _descriptor.Descriptor(
    name="Checkpoint",
    full_name="com.daml.ledger.api.v1.Checkpoint",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="record_time",
            full_name="com.daml.ledger.api.v1.Checkpoint.record_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="com.daml.ledger.api.v1.Checkpoint.offset",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=529,
    serialized_end=644,
)


_COMPLETIONENDREQUEST = _descriptor.Descriptor(
    name="CompletionEndRequest",
    full_name="com.daml.ledger.api.v1.CompletionEndRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ledger_id",
            full_name="com.daml.ledger.api.v1.CompletionEndRequest.ledger_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trace_context",
            full_name="com.daml.ledger.api.v1.CompletionEndRequest.trace_context",
            index=1,
            number=1000,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=646,
    serialized_end=749,
)


_COMPLETIONENDRESPONSE = _descriptor.Descriptor(
    name="CompletionEndResponse",
    full_name="com.daml.ledger.api.v1.CompletionEndResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="com.daml.ledger.api.v1.CompletionEndResponse.offset",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=751,
    serialized_end=828,
)

_COMPLETIONSTREAMREQUEST.fields_by_name[
    "offset"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_ledger__offset__pb2._LEDGEROFFSET
_COMPLETIONSTREAMRESPONSE.fields_by_name["checkpoint"].message_type = _CHECKPOINT
_COMPLETIONSTREAMRESPONSE.fields_by_name[
    "completions"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_completion__pb2._COMPLETION
_CHECKPOINT.fields_by_name[
    "record_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHECKPOINT.fields_by_name[
    "offset"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_ledger__offset__pb2._LEDGEROFFSET
_COMPLETIONENDREQUEST.fields_by_name[
    "trace_context"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2._TRACECONTEXT
_COMPLETIONENDRESPONSE.fields_by_name[
    "offset"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_ledger__offset__pb2._LEDGEROFFSET
DESCRIPTOR.message_types_by_name["CompletionStreamRequest"] = _COMPLETIONSTREAMREQUEST
DESCRIPTOR.message_types_by_name["CompletionStreamResponse"] = _COMPLETIONSTREAMRESPONSE
DESCRIPTOR.message_types_by_name["Checkpoint"] = _CHECKPOINT
DESCRIPTOR.message_types_by_name["CompletionEndRequest"] = _COMPLETIONENDREQUEST
DESCRIPTOR.message_types_by_name["CompletionEndResponse"] = _COMPLETIONENDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CompletionStreamRequest = _reflection.GeneratedProtocolMessageType(
    "CompletionStreamRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETIONSTREAMREQUEST,
        "__module__": "com.daml.ledger.api.v1.command_completion_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CompletionStreamRequest)
    },
)
_sym_db.RegisterMessage(CompletionStreamRequest)

CompletionStreamResponse = _reflection.GeneratedProtocolMessageType(
    "CompletionStreamResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETIONSTREAMRESPONSE,
        "__module__": "com.daml.ledger.api.v1.command_completion_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CompletionStreamResponse)
    },
)
_sym_db.RegisterMessage(CompletionStreamResponse)

Checkpoint = _reflection.GeneratedProtocolMessageType(
    "Checkpoint",
    (_message.Message,),
    {
        "DESCRIPTOR": _CHECKPOINT,
        "__module__": "com.daml.ledger.api.v1.command_completion_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Checkpoint)
    },
)
_sym_db.RegisterMessage(Checkpoint)

CompletionEndRequest = _reflection.GeneratedProtocolMessageType(
    "CompletionEndRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETIONENDREQUEST,
        "__module__": "com.daml.ledger.api.v1.command_completion_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CompletionEndRequest)
    },
)
_sym_db.RegisterMessage(CompletionEndRequest)

CompletionEndResponse = _reflection.GeneratedProtocolMessageType(
    "CompletionEndResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETIONENDRESPONSE,
        "__module__": "com.daml.ledger.api.v1.command_completion_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CompletionEndResponse)
    },
)
_sym_db.RegisterMessage(CompletionEndResponse)


DESCRIPTOR._options = None

_COMMANDCOMPLETIONSERVICE = _descriptor.ServiceDescriptor(
    name="CommandCompletionService",
    full_name="com.daml.ledger.api.v1.CommandCompletionService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=831,
    serialized_end=1088,
    methods=[
        _descriptor.MethodDescriptor(
            name="CompletionStream",
            full_name="com.daml.ledger.api.v1.CommandCompletionService.CompletionStream",
            index=0,
            containing_service=None,
            input_type=_COMPLETIONSTREAMREQUEST,
            output_type=_COMPLETIONSTREAMRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CompletionEnd",
            full_name="com.daml.ledger.api.v1.CommandCompletionService.CompletionEnd",
            index=1,
            containing_service=None,
            input_type=_COMPLETIONENDREQUEST,
            output_type=_COMPLETIONENDRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_COMMANDCOMPLETIONSERVICE)

DESCRIPTOR.services_by_name["CommandCompletionService"] = _COMMANDCOMPLETIONSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/active_contracts_service.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import (
    event_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2,
    trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2,
    transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2,
)

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/active_contracts_service.proto",
    package="com.daml.ledger.api.v1",
    syntax="proto3",
    serialized_options=b"\n\026com.daml.ledger.api.v1B ActiveContractsServiceOuterClass\252\002\026Com.Daml.Ledger.Api.V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n5com/daml/ledger/api/v1/active_contracts_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a"com/daml/ledger/api/v1/event.proto\x1a/com/daml/ledger/api/v1/transaction_filter.proto\x1a*com/daml/ledger/api/v1/trace_context.proto"\xb8\x01\n\x19GetActiveContractsRequest\x12\x11\n\tledger_id\x18\x01 \x01(\t\x12\x39\n\x06\x66ilter\x18\x02 \x01(\x0b\x32).com.daml.ledger.api.v1.TransactionFilter\x12\x0f\n\x07verbose\x18\x03 \x01(\x08\x12<\n\rtrace_context\x18\xe8\x07 \x01(\x0b\x32$.com.daml.ledger.api.v1.TraceContext"\xbf\x01\n\x1aGetActiveContractsResponse\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\t\x12>\n\x10\x61\x63tive_contracts\x18\x03 \x03(\x0b\x32$.com.daml.ledger.api.v1.CreatedEvent\x12<\n\rtrace_context\x18\xe8\x07 \x01(\x0b\x32$.com.daml.ledger.api.v1.TraceContext2\x97\x01\n\x16\x41\x63tiveContractsService\x12}\n\x12GetActiveContracts\x12\x31.com.daml.ledger.api.v1.GetActiveContractsRequest\x1a\x32.com.daml.ledger.api.v1.GetActiveContractsResponse0\x01\x42S\n\x16\x63om.daml.ledger.api.v1B ActiveContractsServiceOuterClass\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3',
    dependencies=[
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2.DESCRIPTOR,
    ],
)


_GETACTIVECONTRACTSREQUEST = _descriptor.Descriptor(
    name="GetActiveContractsRequest",
    full_name="com.daml.ledger.api.v1.GetActiveContractsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ledger_id",
            full_name="com.daml.ledger.api.v1.GetActiveContractsRequest.ledger_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="com.daml.ledger.api.v1.GetActiveContractsRequest.filter",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="verbose",
            full_name="com.daml.ledger.api.v1.GetActiveContractsRequest.verbose",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trace_context",
            full_name="com.daml.ledger.api.v1.GetActiveContractsRequest.trace_context",
            index=3,
            number=1000,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=211,
    serialized_end=395,
)


_GETACTIVECONTRACTSRESPONSE = _descriptor.Descriptor(
    name="GetActiveContractsResponse",
    full_name="com.daml.ledger.api.v1.GetActiveContractsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="com.daml.ledger.api.v1.GetActiveContractsResponse.offset",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="workflow_id",
            full_name="com.daml.ledger.api.v1.GetActiveContractsResponse.workflow_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="active_contracts",
            full_name="com.daml.ledger.api.v1.GetActiveContractsResponse.active_contracts",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trace_context",
            full_name="com.daml.ledger.api.v1.GetActiveContractsResponse.trace_context",
            index=3,
            number=1000,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=398,
    serialized_end=589,
)

_GETACTIVECONTRACTSREQUEST.fields_by_name[
    "filter"
].message_type = (
    com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__filter__pb2._TRANSACTIONFILTER
)
_GETACTIVECONTRACTSREQUEST.fields_by_name[
    "trace_context"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2._TRACECONTEXT
_GETACTIVECONTRACTSRESPONSE.fields_by_name[
    "active_contracts"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_event__pb2._CREATEDEVENT
_GETACTIVECONTRACTSRESPONSE.fields_by_name[
    "trace_context"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2._TRACECONTEXT
DESCRIPTOR.message_types_by_name["GetActiveContractsRequest"] = _GETACTIVECONTRACTSREQUEST
DESCRIPTOR.message_types_by_name["GetActiveContractsResponse"] = _GETACTIVECONTRACTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetActiveContractsRequest = _reflection.GeneratedProtocolMessageType(
    "GetActiveContractsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETACTIVECONTRACTSREQUEST,
        "__module__": "com.daml.ledger.api.v1.active_contracts_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetActiveContractsRequest)
    },
)
_sym_db.RegisterMessage(GetActiveContractsRequest)

GetActiveContractsResponse = _reflection.GeneratedProtocolMessageType(
    "GetActiveContractsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETACTIVECONTRACTSRESPONSE,
        "__module__": "com.daml.ledger.api.v1.active_contracts_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetActiveContractsResponse)
    },
)
_sym_db.RegisterMessage(GetActiveContractsResponse)


DESCRIPTOR._options = None

_ACTIVECONTRACTSSERVICE = _descriptor.ServiceDescriptor(
    name="ActiveContractsService",
    full_name="com.daml.ledger.api.v1.ActiveContractsService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=592,
    serialized_end=743,
    methods=[
        _descriptor.MethodDescriptor(
            name="GetActiveContracts",
            full_name="com.daml.ledger.api.v1.ActiveContractsService.GetActiveContracts",
            index=0,
            containing_service=None,
            input_type=_GETACTIVECONTRACTSREQUEST,
            output_type=_GETACTIVECONTRACTSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ACTIVECONTRACTSSERVICE)

DESCRIPTOR.services_by_name["ActiveContractsService"] = _ACTIVECONTRACTSSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from typing import Generic, Optional, TypeVar

from .daml_lf_1 import (
    Binding,
    Block,
    BuiltinFunction,
    Case,
    Expr,
    FieldWithExpr,
    FieldWithType,
    Module,
    Package,
    PrimCon,
    PrimLit,
    Scenario,
    Type,
    Update,
    ValName,
    VarWithType,
)

E = TypeVar("E", contravariant=True)
RP = TypeVar("RP", covariant=True)
RM = TypeVar("RM", covariant=True)
RE = TypeVar("RE", covariant=True)
RT = TypeVar("RT", covariant=True)
_tuple = tuple


class PackageVisitor(Generic[RP]):
    def visit_package(self, package: "Package") -> "RP":
        raise NotImplementedError


class ModuleVisitor(Generic[RM]):
    def visit_module(self, module: "Module") -> "RM":
        raise NotImplementedError


class ExprVisitor(Generic[RE]):
    def visit_expr(self, expr: "Expr") -> "RE":
        return expr.Sum_match(
            self.visit_expr_var,
            self.visit_expr_val,
            self.visit_expr_builtin,
            self.visit_expr_prim_con,
            self.visit_expr_prim_lit,
            self.visit_expr_rec_con,
            self.visit_expr_rec_proj,
            self.visit_expr_variant_con,
            self.visit_expr_enum_con,
            self.visit_expr_struct_con,
            self.visit_expr_struct_proj,
            self.visit_expr_app,
            self.visit_expr_ty_app,
            self.visit_expr_abs,
            self.visit_expr_ty_abs,
            self.visit_expr_case,
            self.visit_expr_let,
            self.visit_expr_nil,
            self.visit_expr_cons,
            self.visit_expr_update,
            self.visit_expr_scenario,
            self.visit_expr_rec_upd,
            self.visit_expr_struct_upd,
            self.visit_expr_optional_none,
            self.visit_expr_optional_some,
            self.visit_expr_to_any,
            self.visit_expr_from_any,
            self.visit_expr_to_text_template_id,
            self.visit_expr_type_rep,
        )

    def visit_expr_var(self, var: str) -> "RE":
        raise NotImplementedError

    def visit_expr_val(self, val: "ValName") -> "RE":
        raise NotImplementedError

    def visit_expr_builtin(self, builtin: "BuiltinFunction") -> "RE":
        raise NotImplementedError

    def visit_expr_prim_con(self, prim_con: "PrimCon") -> "RE":
        raise NotImplementedError

    def visit_expr_prim_lit(self, prim_lit: "PrimLit") -> "RE":
        raise NotImplementedError

    def visit_expr_rec_con(self, rec_con: "Expr.RecCon") -> "RE":
        raise NotImplementedError

    def visit_expr_rec_proj(self, rec_proj: "Expr.RecProj") -> "RE":
        raise NotImplementedError

    def visit_expr_variant_con(self, variant_con: "Expr.VariantCon") -> "RE":
        raise NotImplementedError

    def visit_expr_enum_con(self, enum_con: "Expr.EnumCon") -> "RE":
        raise NotImplementedError

    def visit_expr_struct_con(self, struct_con: "Expr.StructCon") -> "RE":
        raise NotImplementedError

    def visit_expr_struct_proj(self, struct_proj: "Expr.StructProj") -> "RE":
        raise NotImplementedError

    def visit_expr_app(self, app: "Expr.App") -> "RE":
        raise NotImplementedError

    def visit_expr_ty_app(self, ty_app: "Expr.TyApp") -> "RE":
        raise NotImplementedError

    def visit_expr_abs(self, abs_: "Expr.Abs") -> "RE":
        raise NotImplementedError

    def visit_expr_ty_abs(self, ty_abs: "Expr.TyAbs") -> "RE":
        raise NotImplementedError

    def visit_expr_case(self, case: "Case") -> "RE":
        raise NotImplementedError

    def visit_expr_let(self, let: "Block") -> "RE":
        raise NotImplementedError

    def visit_expr_nil(self, nil: "Expr.Nil") -> "RE":
        raise NotImplementedError

    def visit_expr_cons(self, cons: "Expr.Cons") -> "RE":
        raise NotImplementedError

    def visit_expr_update(self, update: "Update") -> "RE":
        raise NotImplementedError

    def visit_expr_scenario(self, scenario: "Scenario") -> "RE":
        raise NotImplementedError

    def visit_expr_rec_upd(self, rec_upd: "Expr.RecUpd") -> "RE":
        raise NotImplementedError

    def visit_expr_struct_upd(self, struct_upd: "Expr.StructUpd") -> "RE":
        raise NotImplementedError

    def visit_expr_optional_none(self, optional_none: "Expr.OptionalNone") -> "RE":
        raise NotImplementedError

    def visit_expr_optional_some(self, optional_some: "Expr.OptionalSome") -> "RE":
        raise NotImplementedError

    def visit_expr_to_any(self, to_any: "Expr.ToAny") -> "RE":
        raise NotImplementedError

    def visit_expr_from_any(self, from_any: "Expr.FromAny") -> "RE":
        raise NotImplementedError

    def visit_expr_to_text_template_id(self, to_text_template_id: "Expr.ToTextTemplateId") -> "RE":
        raise NotImplementedError

    def visit_expr_type_rep(self, type_rep: "Type") -> "RE":
        raise NotImplementedError


class TypeVisitor(Generic[RT]):
    def visit_type(self, type: "Type") -> "RT":
        return type.Sum_match(
            self.visit_type_var,
            self.visit_type_con,
            self.visit_type_prim,
            self.visit_type_tysyn,
            self.visit_type_forall,
            self.visit_type_tuple,
            self.visit_type_nat,
            self.visit_type_syn,
        )

    def visit_type_var(self, var: "Type.Var") -> "RT":
        raise NotImplementedError

    def visit_type_con(self, con: "Type.Con") -> "RT":
        raise NotImplementedError

    def visit_type_prim(self, prim: "Type.Prim") -> "RT":
        raise NotImplementedError

    def visit_type_tysyn(self, tysyn: "Type.Syn") -> "RT":
        raise NotImplementedError

    def visit_type_forall(self, forall: "Type.Forall") -> "RT":
        raise NotImplementedError

    def visit_type_tuple(self, tuple: "Type.Tuple") -> "RT":
        raise NotImplementedError

    def visit_type_nat(self, nat: int) -> "RT":
        raise NotImplementedError

    def visit_type_syn(self, syn: "Type.Syn") -> "RT":
        raise NotImplementedError


class IdentityTypeVisitor(TypeVisitor[Type]):
    def resolve_type(self, var: "str") -> "Optional[Type]":
        """
        Return a :class:`Type` for the specified variable, or ``None`` if there is no mapping for
        that type variable.
        """
        raise NotImplementedError

    def visit_type_var(self, var: "Type.Var") -> "Type":
        resolved_type = self.resolve_type(var.var)
        if resolved_type is not None:
            base_type = self.visit_type(resolved_type)
        else:
            base_type = Type(var=var)

        if var.args:
            new_args = tuple(self.visit_type(arg) for arg in var.args)
            return Type(var=Type.Var(var=var.var, args=new_args))
        else:
            return base_type

    def visit_type_con(self, con: "Type.Con") -> "Type":
        new_args = tuple(self.visit_type(arg) for arg in con.args)
        return Type(con=Type.Con(tycon=con.tycon, args=new_args))

    def visit_type_prim(self, prim: "Type.Prim") -> "Type":
        new_args = tuple(self.visit_type(arg) for arg in prim.args)
        return Type(prim=Type.Prim(prim=prim.prim, args=new_args))

    def visit_type_forall(self, forall: "Type.Forall") -> "Type":
        new_body = self.visit_type(forall.body)
        return Type(forall=Type.Forall(forall.vars, new_body))

    def visit_type_tuple(self, tuple: "Type.Tuple") -> "Type":
        new_fields = _tuple(
            [FieldWithType(field=fwt.field, type=self.visit_type(fwt.type)) for fwt in tuple.fields]
        )
        return Type(tuple=Type.Tuple(fields=new_fields))

    def visit_type_nat(self, nat: int) -> "Type":
        return Type(nat=nat)


class IdentityVisitor(ExprVisitor[Expr], IdentityTypeVisitor):
    """
    Implementation of :class:`ExprVisitor` that returns the same object for every case.
    """

    def visit_expr(self, expr: "Expr") -> "Expr":
        return super(IdentityVisitor, self).visit_expr(expr)

    def visit_expr_var(self, var: str) -> "Expr":
        return Expr(var=var)

    def visit_expr_val(self, val: "ValName") -> "Expr":
        return Expr(val=val)

    def visit_expr_builtin(self, builtin: "BuiltinFunction") -> "Expr":
        return Expr(builtin=builtin)

    def visit_expr_prim_con(self, prim_con: "PrimCon") -> "Expr":
        return Expr(prim_con=prim_con)

    def visit_expr_prim_lit(self, prim_lit: "PrimLit") -> "Expr":
        return Expr(prim_lit=prim_lit)

    def visit_expr_rec_con(self, rec_con: "Expr.RecCon") -> "Expr":
        new_fields = tuple(
            [FieldWithExpr(fwt.field, self.visit_expr(fwt.expr)) for fwt in rec_con.fields]
        )
        new_tycon = self.visit_type_con(rec_con.tycon).con
        return Expr(rec_con=Expr.RecCon(tycon=new_tycon, fields=new_fields))

    def visit_expr_rec_proj(self, rec_proj: "Expr.RecProj") -> "Expr":
        new_tycon = self.visit_type_con(rec_proj.tycon).con
        new_record = self.visit_expr(rec_proj.record)
        return Expr(rec_proj=Expr.RecProj(tycon=new_tycon, field=rec_proj.field, record=new_record))

    def visit_expr_variant_con(self, variant_con: "Expr.VariantCon") -> "Expr":
        new_type_con = self.visit_type_con(variant_con.tycon).con
        new_variant_arg = self.visit_expr(variant_con.variant_arg)
        return Expr(
            variant_con=Expr.VariantCon(
                tycon=new_type_con, variant_con=variant_con.variant_con, variant_arg=new_variant_arg
            )
        )

    def visit_expr_enum_con(self, enum_con: "Expr.EnumCon") -> "Expr":
        new_type_con = self.visit_type_con(enum_con.tycon).con
        return Expr(enum_con=Expr.EnumCon(tycon=new_type_con, enum_con=enum_con.enum_con))

    def visit_expr_struct_con(self, struct_con: "Expr.StructCon") -> "Expr":
        new_fields = tuple(
            [FieldWithExpr(fwt.field, self.visit_expr(fwt.expr)) for fwt in struct_con.fields]
        )
        return Expr(struct_con=Expr.StructCon(fields=new_fields))

    def visit_expr_struct_proj(self, struct_proj: "Expr.StructProj") -> "Expr":
        new_tuple = self.visit_expr(struct_proj.tuple)
        return Expr(struct_proj=Expr.StructProj(field=struct_proj.field, tuple=new_tuple))

    def visit_expr_app(self, app: "Expr.App") -> "Expr":
        new_fun = self.visit_expr(app.fun)
        new_args = tuple([self.visit_expr(arg) for arg in app.args])
        return Expr(app=Expr.App(new_fun, new_args))

    def visit_expr_ty_app(self, ty_app: "Expr.TyApp") -> "Expr":
        new_expr = self.visit_expr(ty_app.expr)
        new_types = tuple([self.visit_type(t) for t in ty_app.types])
        return Expr(ty_app=Expr.TyApp(new_expr, new_types))

    def visit_expr_abs(self, abs_: "Expr.Abs") -> "Expr":
        new_body = self.visit_expr(abs_.body)
        return Expr(abs=Expr.Abs(param=abs_.param, body=new_body))

    def visit_expr_ty_abs(self, ty_abs: "Expr.TyAbs") -> "Expr":
        new_body = self.visit_expr(ty_abs.body)
        return Expr(ty_abs=Expr.TyAbs(param=ty_abs.param, body=new_body))

    def visit_expr_case(self, case: "Case") -> "Expr":
        new_scrut = self.visit_expr(case.scrut)
        # TODO: Real implementation
        new_alts = [alt for alt in case.alts]
        return Expr(case=Case(scrut=new_scrut, alts=new_alts))

    def visit_expr_let(self, let: "Block") -> "Expr":
        new_bindings = [
            Binding(
                VarWithType(binding.binder.var, self.visit_type(binding.binder.type)),
                self.visit_expr(binding.bound),
            )
            for binding in let.bindings
        ]
        new_body = self.visit_expr(let.body)
        return Expr(let=Block(bindings=new_bindings, body=new_body))

    def visit_expr_nil(self, nil: "Expr.Nil") -> "Expr":
        return Expr(nil=Expr.Nil(self.visit_type(nil.type)))

    def visit_expr_cons(self, cons: "Expr.Cons") -> "Expr":
        new_type = self.visit_type(cons.type)
        new_front = tuple(self.visit_expr(front) for front in cons.front)
        new_tail = self.visit_expr(cons.tail)
        return Expr(cons=Expr.Cons(type=new_type, front=new_front, tail=new_tail))

    def visit_expr_update(self, update: "Update") -> "Expr":
        return Expr(update=update)

    def visit_expr_scenario(self, scenario: "Scenario") -> "Expr":
        return Expr(scenario=scenario)

    def visit_expr_rec_upd(self, rec_upd: "Expr.RecUpd") -> "Expr":
        return Expr(rec_upd=rec_upd)

    def visit_expr_struct_upd(self, struct_upd: "Expr.StructUpd") -> "Expr":
        return Expr(struct_upd=struct_upd)

    def visit_expr_optional_none(self, optional_none: "Expr.OptionalNone") -> "Expr":
        new_type = self.visit_type(optional_none.type)
        return Expr(optional_none=Expr.OptionalNone(type=new_type))

    def visit_expr_optional_some(self, optional_some: "Expr.OptionalSome") -> "Expr":
        new_type = self.visit_type(optional_some.type)
        new_body = self.visit_expr(optional_some.body)
        return Expr(optional_some=Expr.OptionalSome(type=new_type, body=new_body))

    def visit_expr_to_any(self, to_any: "Expr.ToAny") -> "Expr":
        return Expr(
            to_any=Expr.ToAny(type=self.visit_type(to_any.type), expr=self.visit_expr(to_any.expr))
        )

    def visit_expr_from_any(self, from_any: "Expr.FromAny") -> "Expr":
        return Expr(
            from_any=Expr.ToAny(
                type=self.visit_type(from_any.type), expr=self.visit_expr(from_any.expr)
            )
        )

    def visit_expr_to_text_template_id(
        self, to_text_template_id: "Expr.ToTextTemplateId"
    ) -> "Expr":
        return Expr(
            to_text_template_id=Expr.ToTextTemplateId(
                type=self.visit_type(to_text_template_id.type)
            )
        )



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0


from argparse import ArgumentParser

from .. import LOG, Network
from ..client.config import NetworkConfig, configure_parser
from ..pretty.table import DEFAULT_FORMATTER_NAME, write_acs
from ._base import CliCommand


class ListAllCommand(CliCommand):
    name = "ls"

    def parser(self) -> ArgumentParser:
        arg_parser = ArgumentParser("dazl ls")

        configure_parser(arg_parser, config_file_support=True)
        arg_parser.add_argument("--format", "--fmt", "-F", type=str, default=DEFAULT_FORMATTER_NAME)
        arg_parser.add_argument("--template-filter", "-T", type=str)
        arg_parser.add_argument("--all", "-A", action="store_true")
        return arg_parser

    def execute(self, args) -> int:
        fmt = args.format
        template_filter = (
            [template.strip() for template in args.template_filter.split(",")]
            if args.template_filter is not None
            else None
        )
        include_archived = bool(args.all)
        LOG.debug("Executing an ls...")

        final_config = NetworkConfig.get_config(args)

        network = Network()
        network.set_config(final_config)
        network.set_config(eager_package_fetch=False)
        if include_archived:
            network.set_config(use_acs_service=False)

        for party in args.parties:
            network.aio_party(party)

        network.run_until_complete(self._main(network, fmt, include_archived))
        return 0

    async def _main(self, network: "Network", fmt: str, include_archived: bool):
        import sys

        LOG.debug("Starting our parties...")
        for party in network.parties():
            await network.aio_party(party).ready()
            LOG.debug("Party %s is ready.", party)
        metadata = await network.aio_global().metadata()
        LOG.debug("Our parties are now ready.")

        write_acs(sys.stdout, network, fmt=fmt, include_archived=include_archived)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

__all__ = ["CallbackReturnWarning", "ProtocolWarning"]


class CallbackReturnWarning(Warning):
    """
    Raised when a user callback on a stream returns a value. These objects have no meaning and are
    ignored by dazl.

    This warning is raised primarily because older versions of dazl interpreted returning commands
    from a callback as a request to send commands to the underlying ledger, and this is not
    supported in newer APIs.
    """


class ProtocolWarning(Warning):
    """
    Warnings that are raised when dazl detects incompatibilities between the Ledger API server-side
    implementation and dazl.
    """



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/value.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/value.proto",
    package="com.daml.ledger.api.v1",
    syntax="proto3",
    serialized_options=b"\n\026com.daml.ledger.api.v1B\017ValueOuterClass\252\002\026Com.Daml.Ledger.Api.V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n"com/daml/ledger/api/v1/value.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x1bgoogle/protobuf/empty.proto"\xa6\x04\n\x05Value\x12\x30\n\x06record\x18\x01 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.RecordH\x00\x12\x32\n\x07variant\x18\x02 \x01(\x0b\x32\x1f.com.daml.ledger.api.v1.VariantH\x00\x12\x15\n\x0b\x63ontract_id\x18\x03 \x01(\tH\x00\x12,\n\x04list\x18\x04 \x01(\x0b\x32\x1c.com.daml.ledger.api.v1.ListH\x00\x12\x13\n\x05int64\x18\x05 \x01(\x12\x42\x02\x30\x01H\x00\x12\x11\n\x07numeric\x18\x06 \x01(\tH\x00\x12\x0e\n\x04text\x18\x08 \x01(\tH\x00\x12\x17\n\ttimestamp\x18\t \x01(\x10\x42\x02\x30\x01H\x00\x12\x0f\n\x05party\x18\x0b \x01(\tH\x00\x12\x0e\n\x04\x62ool\x18\x0c \x01(\x08H\x00\x12&\n\x04unit\x18\r \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x0e\n\x04\x64\x61te\x18\x0e \x01(\x05H\x00\x12\x34\n\x08optional\x18\x0f \x01(\x0b\x32 .com.daml.ledger.api.v1.OptionalH\x00\x12*\n\x03map\x18\x10 \x01(\x0b\x32\x1b.com.daml.ledger.api.v1.MapH\x00\x12,\n\x04\x65num\x18\x11 \x01(\x0b\x32\x1c.com.daml.ledger.api.v1.EnumH\x00\x12\x31\n\x07gen_map\x18\x12 \x01(\x0b\x32\x1e.com.daml.ledger.api.v1.GenMapH\x00\x42\x05\n\x03Sum"t\n\x06Record\x12\x35\n\trecord_id\x18\x01 \x01(\x0b\x32".com.daml.ledger.api.v1.Identifier\x12\x33\n\x06\x66ields\x18\x02 \x03(\x0b\x32#.com.daml.ledger.api.v1.RecordField"J\n\x0bRecordField\x12\r\n\x05label\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.Value"P\n\nIdentifier\x12\x12\n\npackage_id\x18\x01 \x01(\t\x12\x13\n\x0bmodule_name\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03"\x84\x01\n\x07Variant\x12\x36\n\nvariant_id\x18\x01 \x01(\x0b\x32".com.daml.ledger.api.v1.Identifier\x12\x13\n\x0b\x63onstructor\x18\x02 \x01(\t\x12,\n\x05value\x18\x03 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.Value"P\n\x04\x45num\x12\x33\n\x07\x65num_id\x18\x01 \x01(\x0b\x32".com.daml.ledger.api.v1.Identifier\x12\x13\n\x0b\x63onstructor\x18\x02 \x01(\t"7\n\x04List\x12/\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1d.com.daml.ledger.api.v1.Value"8\n\x08Optional\x12,\n\x05value\x18\x01 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.Value"}\n\x03Map\x12\x32\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.com.daml.ledger.api.v1.Map.Entry\x1a\x42\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.Value"\xa2\x01\n\x06GenMap\x12\x35\n\x07\x65ntries\x18\x01 \x03(\x0b\x32$.com.daml.ledger.api.v1.GenMap.Entry\x1a\x61\n\x05\x45ntry\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.Value\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v1.ValueBB\n\x16\x63om.daml.ledger.api.v1B\x0fValueOuterClass\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
    ],
)


_VALUE = _descriptor.Descriptor(
    name="Value",
    full_name="com.daml.ledger.api.v1.Value",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="record",
            full_name="com.daml.ledger.api.v1.Value.record",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="variant",
            full_name="com.daml.ledger.api.v1.Value.variant",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="contract_id",
            full_name="com.daml.ledger.api.v1.Value.contract_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="list",
            full_name="com.daml.ledger.api.v1.Value.list",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="int64",
            full_name="com.daml.ledger.api.v1.Value.int64",
            index=4,
            number=5,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"0\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="numeric",
            full_name="com.daml.ledger.api.v1.Value.numeric",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="text",
            full_name="com.daml.ledger.api.v1.Value.text",
            index=6,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="timestamp",
            full_name="com.daml.ledger.api.v1.Value.timestamp",
            index=7,
            number=9,
            type=16,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"0\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="party",
            full_name="com.daml.ledger.api.v1.Value.party",
            index=8,
            number=11,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="bool",
            full_name="com.daml.ledger.api.v1.Value.bool",
            index=9,
            number=12,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="unit",
            full_name="com.daml.ledger.api.v1.Value.unit",
            index=10,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="date",
            full_name="com.daml.ledger.api.v1.Value.date",
            index=11,
            number=14,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="optional",
            full_name="com.daml.ledger.api.v1.Value.optional",
            index=12,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="map",
            full_name="com.daml.ledger.api.v1.Value.map",
            index=13,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enum",
            full_name="com.daml.ledger.api.v1.Value.enum",
            index=14,
            number=17,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gen_map",
            full_name="com.daml.ledger.api.v1.Value.gen_map",
            index=15,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="Sum",
            full_name="com.daml.ledger.api.v1.Value.Sum",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=92,
    serialized_end=642,
)


_RECORD = _descriptor.Descriptor(
    name="Record",
    full_name="com.daml.ledger.api.v1.Record",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="record_id",
            full_name="com.daml.ledger.api.v1.Record.record_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="com.daml.ledger.api.v1.Record.fields",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=644,
    serialized_end=760,
)


_RECORDFIELD = _descriptor.Descriptor(
    name="RecordField",
    full_name="com.daml.ledger.api.v1.RecordField",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="label",
            full_name="com.daml.ledger.api.v1.RecordField.label",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="com.daml.ledger.api.v1.RecordField.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=762,
    serialized_end=836,
)


_IDENTIFIER = _descriptor.Descriptor(
    name="Identifier",
    full_name="com.daml.ledger.api.v1.Identifier",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="package_id",
            full_name="com.daml.ledger.api.v1.Identifier.package_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="module_name",
            full_name="com.daml.ledger.api.v1.Identifier.module_name",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="entity_name",
            full_name="com.daml.ledger.api.v1.Identifier.entity_name",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=838,
    serialized_end=918,
)


_VARIANT = _descriptor.Descriptor(
    name="Variant",
    full_name="com.daml.ledger.api.v1.Variant",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="variant_id",
            full_name="com.daml.ledger.api.v1.Variant.variant_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="constructor",
            full_name="com.daml.ledger.api.v1.Variant.constructor",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="com.daml.ledger.api.v1.Variant.value",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=921,
    serialized_end=1053,
)


_ENUM = _descriptor.Descriptor(
    name="Enum",
    full_name="com.daml.ledger.api.v1.Enum",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="enum_id",
            full_name="com.daml.ledger.api.v1.Enum.enum_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="constructor",
            full_name="com.daml.ledger.api.v1.Enum.constructor",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1055,
    serialized_end=1135,
)


_LIST = _descriptor.Descriptor(
    name="List",
    full_name="com.daml.ledger.api.v1.List",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="elements",
            full_name="com.daml.ledger.api.v1.List.elements",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1137,
    serialized_end=1192,
)


_OPTIONAL = _descriptor.Descriptor(
    name="Optional",
    full_name="com.daml.ledger.api.v1.Optional",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="com.daml.ledger.api.v1.Optional.value",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1194,
    serialized_end=1250,
)


_MAP_ENTRY = _descriptor.Descriptor(
    name="Entry",
    full_name="com.daml.ledger.api.v1.Map.Entry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="com.daml.ledger.api.v1.Map.Entry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="com.daml.ledger.api.v1.Map.Entry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1311,
    serialized_end=1377,
)

_MAP = _descriptor.Descriptor(
    name="Map",
    full_name="com.daml.ledger.api.v1.Map",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="com.daml.ledger.api.v1.Map.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _MAP_ENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1252,
    serialized_end=1377,
)


_GENMAP_ENTRY = _descriptor.Descriptor(
    name="Entry",
    full_name="com.daml.ledger.api.v1.GenMap.Entry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="com.daml.ledger.api.v1.GenMap.Entry.key",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="com.daml.ledger.api.v1.GenMap.Entry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1445,
    serialized_end=1542,
)

_GENMAP = _descriptor.Descriptor(
    name="GenMap",
    full_name="com.daml.ledger.api.v1.GenMap",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="com.daml.ledger.api.v1.GenMap.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _GENMAP_ENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1380,
    serialized_end=1542,
)

_VALUE.fields_by_name["record"].message_type = _RECORD
_VALUE.fields_by_name["variant"].message_type = _VARIANT
_VALUE.fields_by_name["list"].message_type = _LIST
_VALUE.fields_by_name["unit"].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_VALUE.fields_by_name["optional"].message_type = _OPTIONAL
_VALUE.fields_by_name["map"].message_type = _MAP
_VALUE.fields_by_name["enum"].message_type = _ENUM
_VALUE.fields_by_name["gen_map"].message_type = _GENMAP
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["record"])
_VALUE.fields_by_name["record"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["variant"])
_VALUE.fields_by_name["variant"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["contract_id"])
_VALUE.fields_by_name["contract_id"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["list"])
_VALUE.fields_by_name["list"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["int64"])
_VALUE.fields_by_name["int64"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["numeric"])
_VALUE.fields_by_name["numeric"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["text"])
_VALUE.fields_by_name["text"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["timestamp"])
_VALUE.fields_by_name["timestamp"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["party"])
_VALUE.fields_by_name["party"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["bool"])
_VALUE.fields_by_name["bool"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["unit"])
_VALUE.fields_by_name["unit"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["date"])
_VALUE.fields_by_name["date"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["optional"])
_VALUE.fields_by_name["optional"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["map"])
_VALUE.fields_by_name["map"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["enum"])
_VALUE.fields_by_name["enum"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_VALUE.oneofs_by_name["Sum"].fields.append(_VALUE.fields_by_name["gen_map"])
_VALUE.fields_by_name["gen_map"].containing_oneof = _VALUE.oneofs_by_name["Sum"]
_RECORD.fields_by_name["record_id"].message_type = _IDENTIFIER
_RECORD.fields_by_name["fields"].message_type = _RECORDFIELD
_RECORDFIELD.fields_by_name["value"].message_type = _VALUE
_VARIANT.fields_by_name["variant_id"].message_type = _IDENTIFIER
_VARIANT.fields_by_name["value"].message_type = _VALUE
_ENUM.fields_by_name["enum_id"].message_type = _IDENTIFIER
_LIST.fields_by_name["elements"].message_type = _VALUE
_OPTIONAL.fields_by_name["value"].message_type = _VALUE
_MAP_ENTRY.fields_by_name["value"].message_type = _VALUE
_MAP_ENTRY.containing_type = _MAP
_MAP.fields_by_name["entries"].message_type = _MAP_ENTRY
_GENMAP_ENTRY.fields_by_name["key"].message_type = _VALUE
_GENMAP_ENTRY.fields_by_name["value"].message_type = _VALUE
_GENMAP_ENTRY.containing_type = _GENMAP
_GENMAP.fields_by_name["entries"].message_type = _GENMAP_ENTRY
DESCRIPTOR.message_types_by_name["Value"] = _VALUE
DESCRIPTOR.message_types_by_name["Record"] = _RECORD
DESCRIPTOR.message_types_by_name["RecordField"] = _RECORDFIELD
DESCRIPTOR.message_types_by_name["Identifier"] = _IDENTIFIER
DESCRIPTOR.message_types_by_name["Variant"] = _VARIANT
DESCRIPTOR.message_types_by_name["Enum"] = _ENUM
DESCRIPTOR.message_types_by_name["List"] = _LIST
DESCRIPTOR.message_types_by_name["Optional"] = _OPTIONAL
DESCRIPTOR.message_types_by_name["Map"] = _MAP
DESCRIPTOR.message_types_by_name["GenMap"] = _GENMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType(
    "Value",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALUE,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Value)
    },
)
_sym_db.RegisterMessage(Value)

Record = _reflection.GeneratedProtocolMessageType(
    "Record",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECORD,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Record)
    },
)
_sym_db.RegisterMessage(Record)

RecordField = _reflection.GeneratedProtocolMessageType(
    "RecordField",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECORDFIELD,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.RecordField)
    },
)
_sym_db.RegisterMessage(RecordField)

Identifier = _reflection.GeneratedProtocolMessageType(
    "Identifier",
    (_message.Message,),
    {
        "DESCRIPTOR": _IDENTIFIER,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Identifier)
    },
)
_sym_db.RegisterMessage(Identifier)

Variant = _reflection.GeneratedProtocolMessageType(
    "Variant",
    (_message.Message,),
    {
        "DESCRIPTOR": _VARIANT,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Variant)
    },
)
_sym_db.RegisterMessage(Variant)

Enum = _reflection.GeneratedProtocolMessageType(
    "Enum",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENUM,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Enum)
    },
)
_sym_db.RegisterMessage(Enum)

List = _reflection.GeneratedProtocolMessageType(
    "List",
    (_message.Message,),
    {
        "DESCRIPTOR": _LIST,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.List)
    },
)
_sym_db.RegisterMessage(List)

Optional = _reflection.GeneratedProtocolMessageType(
    "Optional",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPTIONAL,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Optional)
    },
)
_sym_db.RegisterMessage(Optional)

Map = _reflection.GeneratedProtocolMessageType(
    "Map",
    (_message.Message,),
    {
        "Entry": _reflection.GeneratedProtocolMessageType(
            "Entry",
            (_message.Message,),
            {
                "DESCRIPTOR": _MAP_ENTRY,
                "__module__": "com.daml.ledger.api.v1.value_pb2"
                # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Map.Entry)
            },
        ),
        "DESCRIPTOR": _MAP,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.Map)
    },
)
_sym_db.RegisterMessage(Map)
_sym_db.RegisterMessage(Map.Entry)

GenMap = _reflection.GeneratedProtocolMessageType(
    "GenMap",
    (_message.Message,),
    {
        "Entry": _reflection.GeneratedProtocolMessageType(
            "Entry",
            (_message.Message,),
            {
                "DESCRIPTOR": _GENMAP_ENTRY,
                "__module__": "com.daml.ledger.api.v1.value_pb2"
                # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GenMap.Entry)
            },
        ),
        "DESCRIPTOR": _GENMAP,
        "__module__": "com.daml.ledger.api.v1.value_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GenMap)
    },
)
_sym_db.RegisterMessage(GenMap)
_sym_db.RegisterMessage(GenMap.Entry)


DESCRIPTOR._options = None
_VALUE.fields_by_name["int64"]._options = None
_VALUE.fields_by_name["timestamp"]._options = None
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
Types that describe the behavior of the ledger itself.
"""
from dataclasses import dataclass

from dazl.ledger.pkgloader_aio import PackageLoader

from ..protocols.serializers import Serializer


@dataclass(init=False, frozen=True)
class LedgerMetadata:
    """
    Attributes that are invariant with respect to any party on the ledger.
    """

    ledger_id: str
    package_loader: "PackageLoader"
    serializer: "Serializer"
    protocol_version: str

    def __init__(self, ledger_id, package_loader, serializer, protocol_version):
        object.__setattr__(self, "ledger_id", ledger_id)
        object.__setattr__(self, "package_loader", package_loader)
        object.__setattr__(self, "serializer", serializer)
        object.__setattr__(self, "protocol_version", protocol_version)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/admin/package_management_service.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/admin/package_management_service.proto",
    package="com.daml.ledger.api.v1.admin",
    syntax="proto3",
    serialized_options=b'\n\034com.daml.ledger.api.v1.adminB"PackageManagementServiceOuterClass\252\002\034Com.Daml.Ledger.Api.V1.Admin',
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n=com/daml/ledger/api/v1/admin/package_management_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\x1fgoogle/protobuf/timestamp.proto"\x1a\n\x18ListKnownPackagesRequest"b\n\x19ListKnownPackagesResponse\x12\x45\n\x0fpackage_details\x18\x01 \x03(\x0b\x32,.com.daml.ledger.api.v1.admin.PackageDetails"\x87\x01\n\x0ePackageDetails\x12\x12\n\npackage_id\x18\x01 \x01(\t\x12\x14\n\x0cpackage_size\x18\x02 \x01(\x04\x12/\n\x0bknown_since\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_description\x18\x04 \x01(\t"?\n\x14UploadDarFileRequest\x12\x10\n\x08\x64\x61r_file\x18\x01 \x01(\x0c\x12\x15\n\rsubmission_id\x18\x02 \x01(\t"\x17\n\x15UploadDarFileResponse2\x9b\x02\n\x18PackageManagementService\x12\x84\x01\n\x11ListKnownPackages\x12\x36.com.daml.ledger.api.v1.admin.ListKnownPackagesRequest\x1a\x37.com.daml.ledger.api.v1.admin.ListKnownPackagesResponse\x12x\n\rUploadDarFile\x12\x32.com.daml.ledger.api.v1.admin.UploadDarFileRequest\x1a\x33.com.daml.ledger.api.v1.admin.UploadDarFileResponseBa\n\x1c\x63om.daml.ledger.api.v1.adminB"PackageManagementServiceOuterClass\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_LISTKNOWNPACKAGESREQUEST = _descriptor.Descriptor(
    name="ListKnownPackagesRequest",
    full_name="com.daml.ledger.api.v1.admin.ListKnownPackagesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=128,
    serialized_end=154,
)


_LISTKNOWNPACKAGESRESPONSE = _descriptor.Descriptor(
    name="ListKnownPackagesResponse",
    full_name="com.daml.ledger.api.v1.admin.ListKnownPackagesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="package_details",
            full_name="com.daml.ledger.api.v1.admin.ListKnownPackagesResponse.package_details",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=156,
    serialized_end=254,
)


_PACKAGEDETAILS = _descriptor.Descriptor(
    name="PackageDetails",
    full_name="com.daml.ledger.api.v1.admin.PackageDetails",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="package_id",
            full_name="com.daml.ledger.api.v1.admin.PackageDetails.package_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="package_size",
            full_name="com.daml.ledger.api.v1.admin.PackageDetails.package_size",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="known_since",
            full_name="com.daml.ledger.api.v1.admin.PackageDetails.known_since",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="source_description",
            full_name="com.daml.ledger.api.v1.admin.PackageDetails.source_description",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=257,
    serialized_end=392,
)


_UPLOADDARFILEREQUEST = _descriptor.Descriptor(
    name="UploadDarFileRequest",
    full_name="com.daml.ledger.api.v1.admin.UploadDarFileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="dar_file",
            full_name="com.daml.ledger.api.v1.admin.UploadDarFileRequest.dar_file",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="submission_id",
            full_name="com.daml.ledger.api.v1.admin.UploadDarFileRequest.submission_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=394,
    serialized_end=457,
)


_UPLOADDARFILERESPONSE = _descriptor.Descriptor(
    name="UploadDarFileResponse",
    full_name="com.daml.ledger.api.v1.admin.UploadDarFileResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=459,
    serialized_end=482,
)

_LISTKNOWNPACKAGESRESPONSE.fields_by_name["package_details"].message_type = _PACKAGEDETAILS
_PACKAGEDETAILS.fields_by_name[
    "known_since"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name["ListKnownPackagesRequest"] = _LISTKNOWNPACKAGESREQUEST
DESCRIPTOR.message_types_by_name["ListKnownPackagesResponse"] = _LISTKNOWNPACKAGESRESPONSE
DESCRIPTOR.message_types_by_name["PackageDetails"] = _PACKAGEDETAILS
DESCRIPTOR.message_types_by_name["UploadDarFileRequest"] = _UPLOADDARFILEREQUEST
DESCRIPTOR.message_types_by_name["UploadDarFileResponse"] = _UPLOADDARFILERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListKnownPackagesRequest = _reflection.GeneratedProtocolMessageType(
    "ListKnownPackagesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWNPACKAGESREQUEST,
        "__module__": "com.daml.ledger.api.v1.admin.package_management_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListKnownPackagesRequest)
    },
)
_sym_db.RegisterMessage(ListKnownPackagesRequest)

ListKnownPackagesResponse = _reflection.GeneratedProtocolMessageType(
    "ListKnownPackagesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWNPACKAGESRESPONSE,
        "__module__": "com.daml.ledger.api.v1.admin.package_management_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ListKnownPackagesResponse)
    },
)
_sym_db.RegisterMessage(ListKnownPackagesResponse)

PackageDetails = _reflection.GeneratedProtocolMessageType(
    "PackageDetails",
    (_message.Message,),
    {
        "DESCRIPTOR": _PACKAGEDETAILS,
        "__module__": "com.daml.ledger.api.v1.admin.package_management_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.PackageDetails)
    },
)
_sym_db.RegisterMessage(PackageDetails)

UploadDarFileRequest = _reflection.GeneratedProtocolMessageType(
    "UploadDarFileRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPLOADDARFILEREQUEST,
        "__module__": "com.daml.ledger.api.v1.admin.package_management_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.UploadDarFileRequest)
    },
)
_sym_db.RegisterMessage(UploadDarFileRequest)

UploadDarFileResponse = _reflection.GeneratedProtocolMessageType(
    "UploadDarFileResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPLOADDARFILERESPONSE,
        "__module__": "com.daml.ledger.api.v1.admin.package_management_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.UploadDarFileResponse)
    },
)
_sym_db.RegisterMessage(UploadDarFileResponse)


DESCRIPTOR._options = None

_PACKAGEMANAGEMENTSERVICE = _descriptor.ServiceDescriptor(
    name="PackageManagementService",
    full_name="com.daml.ledger.api.v1.admin.PackageManagementService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=485,
    serialized_end=768,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListKnownPackages",
            full_name="com.daml.ledger.api.v1.admin.PackageManagementService.ListKnownPackages",
            index=0,
            containing_service=None,
            input_type=_LISTKNOWNPACKAGESREQUEST,
            output_type=_LISTKNOWNPACKAGESRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UploadDarFile",
            full_name="com.daml.ledger.api.v1.admin.PackageManagementService.UploadDarFile",
            index=1,
            containing_service=None,
            input_type=_UPLOADDARFILEREQUEST,
            output_type=_UPLOADDARFILERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_PACKAGEMANAGEMENTSERVICE)

DESCRIPTOR.services_by_name["PackageManagementService"] = _PACKAGEMANAGEMENTSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/command_service.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

from . import (
    commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_commands__pb2,
    trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2,
    transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__pb2,
)

DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/command_service.proto",
    package="com.daml.ledger.api.v1",
    syntax="proto3",
    serialized_options=b"\n\026com.daml.ledger.api.v1B\030CommandServiceOuterClass\252\002\026Com.Daml.Ledger.Api.V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n,com/daml/ledger/api/v1/command_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a%com/daml/ledger/api/v1/commands.proto\x1a*com/daml/ledger/api/v1/trace_context.proto\x1a(com/daml/ledger/api/v1/transaction.proto\x1a\x1bgoogle/protobuf/empty.proto"\x88\x01\n\x14SubmitAndWaitRequest\x12\x32\n\x08\x63ommands\x18\x01 \x01(\x0b\x32 .com.daml.ledger.api.v1.Commands\x12<\n\rtrace_context\x18\xe8\x07 \x01(\x0b\x32$.com.daml.ledger.api.v1.TraceContext"?\n%SubmitAndWaitForTransactionIdResponse\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t"_\n#SubmitAndWaitForTransactionResponse\x12\x38\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v1.Transaction"g\n\'SubmitAndWaitForTransactionTreeResponse\x12<\n\x0btransaction\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v1.TransactionTree2\x94\x04\n\x0e\x43ommandService\x12U\n\rSubmitAndWait\x12,.com.daml.ledger.api.v1.SubmitAndWaitRequest\x1a\x16.google.protobuf.Empty\x12\x8c\x01\n\x1dSubmitAndWaitForTransactionId\x12,.com.daml.ledger.api.v1.SubmitAndWaitRequest\x1a=.com.daml.ledger.api.v1.SubmitAndWaitForTransactionIdResponse\x12\x88\x01\n\x1bSubmitAndWaitForTransaction\x12,.com.daml.ledger.api.v1.SubmitAndWaitRequest\x1a;.com.daml.ledger.api.v1.SubmitAndWaitForTransactionResponse\x12\x90\x01\n\x1fSubmitAndWaitForTransactionTree\x12,.com.daml.ledger.api.v1.SubmitAndWaitRequest\x1a?.com.daml.ledger.api.v1.SubmitAndWaitForTransactionTreeResponseBK\n\x16\x63om.daml.ledger.api.v1B\x18\x43ommandServiceOuterClass\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3',
    dependencies=[
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_commands__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2.DESCRIPTOR,
        com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
    ],
)


_SUBMITANDWAITREQUEST = _descriptor.Descriptor(
    name="SubmitAndWaitRequest",
    full_name="com.daml.ledger.api.v1.SubmitAndWaitRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="commands",
            full_name="com.daml.ledger.api.v1.SubmitAndWaitRequest.commands",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trace_context",
            full_name="com.daml.ledger.api.v1.SubmitAndWaitRequest.trace_context",
            index=1,
            number=1000,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=227,
    serialized_end=363,
)


_SUBMITANDWAITFORTRANSACTIONIDRESPONSE = _descriptor.Descriptor(
    name="SubmitAndWaitForTransactionIdResponse",
    full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionIdResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transaction_id",
            full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionIdResponse.transaction_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=365,
    serialized_end=428,
)


_SUBMITANDWAITFORTRANSACTIONRESPONSE = _descriptor.Descriptor(
    name="SubmitAndWaitForTransactionResponse",
    full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transaction",
            full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionResponse.transaction",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=430,
    serialized_end=525,
)


_SUBMITANDWAITFORTRANSACTIONTREERESPONSE = _descriptor.Descriptor(
    name="SubmitAndWaitForTransactionTreeResponse",
    full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionTreeResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transaction",
            full_name="com.daml.ledger.api.v1.SubmitAndWaitForTransactionTreeResponse.transaction",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=527,
    serialized_end=630,
)

_SUBMITANDWAITREQUEST.fields_by_name[
    "commands"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_commands__pb2._COMMANDS
_SUBMITANDWAITREQUEST.fields_by_name[
    "trace_context"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_trace__context__pb2._TRACECONTEXT
_SUBMITANDWAITFORTRANSACTIONRESPONSE.fields_by_name[
    "transaction"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__pb2._TRANSACTION
_SUBMITANDWAITFORTRANSACTIONTREERESPONSE.fields_by_name[
    "transaction"
].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_transaction__pb2._TRANSACTIONTREE
DESCRIPTOR.message_types_by_name["SubmitAndWaitRequest"] = _SUBMITANDWAITREQUEST
DESCRIPTOR.message_types_by_name[
    "SubmitAndWaitForTransactionIdResponse"
] = _SUBMITANDWAITFORTRANSACTIONIDRESPONSE
DESCRIPTOR.message_types_by_name[
    "SubmitAndWaitForTransactionResponse"
] = _SUBMITANDWAITFORTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name[
    "SubmitAndWaitForTransactionTreeResponse"
] = _SUBMITANDWAITFORTRANSACTIONTREERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitAndWaitRequest = _reflection.GeneratedProtocolMessageType(
    "SubmitAndWaitRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SUBMITANDWAITREQUEST,
        "__module__": "com.daml.ledger.api.v1.command_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.SubmitAndWaitRequest)
    },
)
_sym_db.RegisterMessage(SubmitAndWaitRequest)

SubmitAndWaitForTransactionIdResponse = _reflection.GeneratedProtocolMessageType(
    "SubmitAndWaitForTransactionIdResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SUBMITANDWAITFORTRANSACTIONIDRESPONSE,
        "__module__": "com.daml.ledger.api.v1.command_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.SubmitAndWaitForTransactionIdResponse)
    },
)
_sym_db.RegisterMessage(SubmitAndWaitForTransactionIdResponse)

SubmitAndWaitForTransactionResponse = _reflection.GeneratedProtocolMessageType(
    "SubmitAndWaitForTransactionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SUBMITANDWAITFORTRANSACTIONRESPONSE,
        "__module__": "com.daml.ledger.api.v1.command_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.SubmitAndWaitForTransactionResponse)
    },
)
_sym_db.RegisterMessage(SubmitAndWaitForTransactionResponse)

SubmitAndWaitForTransactionTreeResponse = _reflection.GeneratedProtocolMessageType(
    "SubmitAndWaitForTransactionTreeResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SUBMITANDWAITFORTRANSACTIONTREERESPONSE,
        "__module__": "com.daml.ledger.api.v1.command_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.SubmitAndWaitForTransactionTreeResponse)
    },
)
_sym_db.RegisterMessage(SubmitAndWaitForTransactionTreeResponse)


DESCRIPTOR._options = None

_COMMANDSERVICE = _descriptor.ServiceDescriptor(
    name="CommandService",
    full_name="com.daml.ledger.api.v1.CommandService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=633,
    serialized_end=1165,
    methods=[
        _descriptor.MethodDescriptor(
            name="SubmitAndWait",
            full_name="com.daml.ledger.api.v1.CommandService.SubmitAndWait",
            index=0,
            containing_service=None,
            input_type=_SUBMITANDWAITREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SubmitAndWaitForTransactionId",
            full_name="com.daml.ledger.api.v1.CommandService.SubmitAndWaitForTransactionId",
            index=1,
            containing_service=None,
            input_type=_SUBMITANDWAITREQUEST,
            output_type=_SUBMITANDWAITFORTRANSACTIONIDRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SubmitAndWaitForTransaction",
            full_name="com.daml.ledger.api.v1.CommandService.SubmitAndWaitForTransaction",
            index=2,
            containing_service=None,
            input_type=_SUBMITANDWAITREQUEST,
            output_type=_SUBMITANDWAITFORTRANSACTIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SubmitAndWaitForTransactionTree",
            full_name="com.daml.ledger.api.v1.CommandService.SubmitAndWaitForTransactionTree",
            index=3,
            containing_service=None,
            input_type=_SUBMITANDWAITREQUEST,
            output_type=_SUBMITANDWAITFORTRANSACTIONTREERESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_COMMANDSERVICE)

DESCRIPTOR.services_by_name["CommandService"] = _COMMANDSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
from typing import Callable

from ._base import T
from .daml_lf_1 import PrimType, Type


def match_prim_type(
    prim_type: "Type.Prim",
    on_unit: "Callable[[], T]",
    on_bool: "Callable[[], T]",
    on_int: "Callable[[], T]",
    on_decimal: "Callable[[], T]",
    on_text: "Callable[[], T]",
    on_datetime: "Callable[[], T]",
    on_timedelta: "Callable[[], T]",
    on_party: "Callable[[], T]",
    on_list: "Callable[[Type], T]",
    on_update: "Callable[[Type], T]",
    on_scenario: "Callable[[Type], T]",
    on_date: "Callable[[], T]",
    on_contract_id: "Callable[[Type], T]",
    on_optional: "Callable[[Type], T]",
    on_arrow: "Callable[[Type, Type], T]",
    on_text_map: "Callable[[Type], T]",
    on_numeric: "Callable[[int], T]",
    on_any: "Callable[[], T]",
    on_type_rep: "Callable[[], T]",
    on_gen_map: "Callable[[Type, Type], T]",
) -> "T":
    if prim_type.prim == PrimType.UNIT:
        return on_unit()
    elif prim_type.prim == PrimType.BOOL:
        return on_bool()
    elif prim_type.prim == PrimType.INT64:
        return on_int()
    elif prim_type.prim == PrimType.DECIMAL:
        return on_decimal()
    elif prim_type.prim == PrimType.TEXT or prim_type.prim == PrimType.CHAR:
        return on_text()
    elif prim_type.prim == PrimType.TIMESTAMP:
        return on_datetime()
    elif prim_type.prim == PrimType.RELTIME:
        return on_timedelta()
    elif prim_type.prim == PrimType.PARTY:
        return on_party()
    elif prim_type.prim == PrimType.LIST:
        return on_list(prim_type.args[0])
    elif prim_type.prim == PrimType.UPDATE:
        return on_update(prim_type.args[0])
    elif prim_type.prim == PrimType.SCENARIO:
        return on_scenario(prim_type.args[0])
    elif prim_type.prim == PrimType.DATE:
        return on_date()
    elif prim_type.prim == PrimType.CONTRACT_ID:
        return on_contract_id(prim_type.args[0])
    elif prim_type.prim == PrimType.OPTIONAL:
        return on_optional(prim_type.args[0])
    elif prim_type.prim == PrimType.ARROW:
        return on_arrow(prim_type.args[0], prim_type.args[1])
    elif prim_type.prim == PrimType.TEXTMAP:
        return on_text_map(prim_type.args[0])
    elif prim_type.prim == PrimType.NUMERIC:
        return on_numeric(prim_type.args[0].nat)
    elif prim_type.prim == PrimType.ANY:
        return on_any()
    elif prim_type.prim == PrimType.TYPE_REP:
        return on_type_rep()
    elif prim_type.prim == PrimType.GENMAP:
        return on_gen_map(prim_type.args[0], prim_type.args[1])
    else:
        raise ValueError(f"undefined PrimType: {prim_type}")



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
"""
Support for exposing dazl's configuration parameters through :mod:`argparse`.
"""
import argparse
from argparse import SUPPRESS, Action, ArgumentParser
import os
from typing import TYPE_CHECKING, Optional, Sequence
import warnings

from .exc import ConfigWarning
from .url import DEFAULT_CONNECT_TIMEOUT, KNOWN_SCHEME_PORTS

if TYPE_CHECKING:
    from argparse import _ArgumentGroup

__all__ = ["configure_parser", "EXAMPLES"]


# Implementation notes:
#
# A common trick employed throughout this file is to add an "argument" to a parser that is not
# directly used. Calling ``add_arguments(...)`` with a "name" of a completely arbitrary string that
# is not practically possible to be called from the command line (for example,
# ``add_arguments("--my-special-flag SOMETHING | -m BLAH")`` is entirely allowed. This also renders
# as-is in the help strings. Additionally, passing nargs=SUPPRESS essentially prevents the flag from
# being used during parsing, but does NOT remove it from help! The opposite (passing help=SUPPRESS)
# can be used to hide the "real" arguments from the help string that would otherwise render in an
# ugly way. This leads to this:
#
#   # argparse does not support different metavars for different arguments, so one arg for the
#   # help string we want, and two more args for the two different cases
#   parser.add_argument("--something STUFF | --something-file TOKEN", nargs=SUPPRESS)
#   parser.add_argument("--something", help=SUPPRESS, ...)
#   parser.add_argument("--something-file", help=SUPPRESS, ...)

# An example string that can be used to help illustrate how to use common flags.
EXAMPLES = """
  # connect to a local sandbox acting as Alice and Bob, with Carol read-only
  # (localhost is the default if no url/host is specified)
  %(prog)s -u Alice,Bob -r Carol

  # connect to myledger.daml.app over SSL/TLS using the access token in "token.txt"
  %(prog)s --url https://myledger.daml.app/ --oauth-token-file token.txt
"""


class WideHelpFormatter(argparse.HelpFormatter):
    def __init__(self, prog: str, *args, **kwargs):
        if "max_help_position" not in kwargs:
            kwargs["max_help_position"] = 43
        if "width" not in kwargs:
            col = os.getenv("COLUMNS")
            if col:
                kwargs["width"] = int(col)

        super().__init__(prog, *args, **kwargs)


def configure_parser(parser: ArgumentParser, add_usage: bool = True) -> None:
    """
    Add dazl configuration options to an existing :class:`ArgumentParser`.

    dazl exposes a variety of configuration options that could be tedious to duplicate in your own
    application. To use this in your own application:

    .. code-block:: python

        parser = argparse.ArgumentParser(description='Something awesome with dazl.')
        configure_parser(parser)
        args = parser.parse_args()

        conn = dazl.connect(**args)

    :param parser:
        The :class:`ArgumentParser` to add options to.
    :param add_usage:
        ``True`` to overwrite the usage string with something more compact; because there are a
        lot of variables, the default usage string doesn't add much
    """
    if add_usage:
        parser.usage = "%(prog)s [OPTIONS]\n\n" + EXAMPLES

    _configure_url_basic_options(parser)
    _configure_access(parser)
    _configure_url_advanced_options(parser)
    _configure_deprecated_options(parser)


def _configure_access(parser: ArgumentParser):
    group_p = parser.add_argument_group("Access configuration (property-based)")

    group_p.add_argument("--act-as/-u PARTY [PARTY ...]", nargs=SUPPRESS, help="act-as parties")
    group_p.add_argument(
        "--act-as",
        "-u",
        "--party",
        "--parties",
        help=SUPPRESS,
        action=AppendPartySetAction,
    )
    group_p.add_argument("--read-as/-r PARTY [PARTY ...]", nargs=SUPPRESS, help="read-as parties")
    group_p.add_argument(
        "--read-as",
        "-r",
        "--party-groups",
        help=SUPPRESS,
        action=AppendPartySetAction,
    )

    group_p.add_argument(
        "--admin",
        action="store_const",
        const=True,
        help="Add admin flag (HTTP JSON API only)",
    )
    group_p.add_argument(
        "--ledger-id",
        "-l",
        help="ledger ID (required on HTTP JSON API)",
    )
    group_p.add_argument(
        "--application-name",
        metavar="NAME",
        help="application name; uniquely identifies this client to the server",
    )

    group_t = parser.add_argument_group("Access configuration (token-based)")
    add_text_or_file_argument(
        group_t,
        "--oauth-token",
        metavar="TOKEN",
        help="OAuth2 bearer token",
    )


def _configure_url_basic_options(parser: ArgumentParser):
    url = parser.add_argument_group("Basic options")
    url.add_argument(
        "--url",
        help="URL of the gRPC Ledger API/HTTP JSON API (cannot be used with --host/--port)",
    )
    # kept around for backwards compatibility
    url.add_argument("--participant-url", dest="url", help=argparse.SUPPRESS)

    host_help = "ledger host (cannot be used with --url; default: localhost)"
    url.add_argument("--host/-H HOST", help=host_help, nargs=SUPPRESS)
    url.add_argument("--host", "-h", help=SUPPRESS)

    # The --port field. Note that -p used to mean parties, but now it means port; this is a little
    # hook to preserve backwards compatibility for one version (as it turns out, the value of the
    # -p flag CAN disambiguate usage so we keep the CLI user-friendly, even it gets a little ugly
    # under the hood for dazl v8
    port_help = "ledger port (cannot be used with --url; default: based on scheme/host)"
    url.add_argument("--port/-p PORT", help=port_help, nargs=SUPPRESS)
    url.add_argument("--port", metavar="PORT", help=SUPPRESS, type=int)
    url.add_argument("-p", action=DashPAction, help=SUPPRESS)

    url.add_argument(
        "--scheme",
        help="scheme/protocol (cannot be used with --url)",
        choices=KNOWN_SCHEME_PORTS,
    )


def _configure_url_advanced_options(parser: ArgumentParser):
    group = parser.add_argument_group("Advanced options")
    LOG_LEVELS = ["verbose", "debug", "info", "warn", "error"]
    group.add_argument(
        "--log-level",
        metavar="LEVEL",
        choices=LOG_LEVELS,
        help=f"logging level (one of {{{','.join(LOG_LEVELS)}}}; default: warn)",
    )
    group.add_argument(
        "--connect-timeout",
        metavar="SECONDS",
        type=float,
        help="number of seconds before giving up on a connection "
        f"(default: {DEFAULT_CONNECT_TIMEOUT.total_seconds()})",
    )

    group.add_argument(
        "--plaintext",
        help="force the connection to use plaintext instead of SSL/TLS",
        dest="scheme",
        action="store_const",
        const="http",
    )

    add_text_or_file_argument(
        group,
        "--cert",
        metavar="CERT",
        help="client certificate (mutual TLS)",
    )
    add_text_or_file_argument(
        group,
        "--cert-key",
        metavar="CERT",
        help="client certificate private key (mutual TLS)",
    )
    add_text_or_file_argument(
        group,
        "--ca",
        metavar="CA",
        help="certificate authority",
    )
    add_bool_argument(
        group,
        "--use-http-proxy",
        hidden_true_flags=["--enable-http-proxy"],
        help="allow/disallow HTTP proxy server usage (default: use, except for localhost)",
    )
    group.add_argument(
        "--package-fetch-poll-interval",
        metavar="SECONDS",
        type=int,
        help="how frequently to fetch ALL packages (default: 0 [don't periodically fetch])",
    )
    # for backwards compatibility; remove in dazl v9
    group.add_argument(
        "--eager-package-fetch",
        action="store_const",
        dest="package_fetch_poll_interval",
        const=1,
        help=SUPPRESS,
    )


def _configure_deprecated_options(parser: ArgumentParser):
    add_no_effect_deprecated_flag(parser, "--idle-timeout")
    add_no_effect_deprecated_flag(parser, "--max-command-batch-timeout")
    add_no_effect_deprecated_flag(parser, "--max-connection-batch-size")
    add_no_effect_deprecated_flag(parser, "--max-connection-count")
    add_no_effect_deprecated_flag(parser, "--max-consequence-depth")
    add_no_effect_deprecated_flag(parser, "--max-event-block-size")
    add_no_effect_deprecated_flag(parser, "--poll-interval")
    add_no_effect_deprecated_flag(parser, "--quiet-count")
    add_no_effect_deprecated_flag(parser, "--use-acs-service", nargs=0)


def add_no_effect_deprecated_flag(parser, *name_or_flags: str, **kwargs):
    """
    Add a flag that can be passed in, but does
    """
    parser.add_argument(
        *name_or_flags,
        action=IgnoreAction,
        warning=f"{'/'.join(name_or_flags)} is no longer used and has no effect; "
        "this flag will be removed in dazl v9",
        help=argparse.SUPPRESS,
        **kwargs,
    )


# noinspection PyShadowingBuiltins
def add_text_or_file_argument(
    parser: "_ArgumentGroup",
    *name_or_flags: str,
    metavar: "Optional[str]" = None,
    metavar_file: str = "FILE",
    help: "Optional[str]" = None,
) -> None:
    """
    Add a (user-facing) argument that can be passed in as a text value on the command-line or as a
    file.

    Note that this actually adds _two_ arguments, one for the base case where a string is passed in
    and another to handle files. This is in line with what :meth:`Config.create` expects.
    """
    if help == SUPPRESS:
        # we may enable this one day, but for now we're the only ones allowed to play weird games
        # with argparse
        raise ValueError("SUPPRESS is not supported here")

    # The first "argument" that we add is actually just for purposes of displaying a nice help
    # string; it is not directly usable
    file_flags = [f"{flag}-file" for flag in name_or_flags if flag.startswith("--")]

    if metavar is None:
        metavar = "STRING"

    parser.add_argument(
        f"{'/'.join(name_or_flags)} {metavar} | {'/'.join(file_flags)} {metavar_file}",
        action=IgnoreAction,
        nargs=SUPPRESS,
        help=help,
    )
    parser.add_argument(*name_or_flags, help=argparse.SUPPRESS)
    parser.add_argument(*file_flags, help=argparse.SUPPRESS)


# noinspection PyShadowingBuiltins
def add_bool_argument(
    parser: "_ArgumentGroup",
    *name_or_flags: str,
    hidden_true_flags: "Optional[Sequence[str]]" = None,
    help: "Optional[str]" = None,
):
    """
    This is partially an alternative to Python 3.9's argparse.BooleanOptionalAction, but this
    function additionally renders help text in a more compact form, while also allowing for
    deprecated identifiers.
    """
    if len(name_or_flags) != 1:
        raise ValueError("can only supply one flag")
    flag = name_or_flags[0]
    if not flag.startswith("--"):
        raise ValueError("flag must start with --")

    base_flag = flag[2:]
    dest = base_flag.replace("-", "_")

    parser.add_argument(
        f"--[no-]{base_flag}",
        help=help,
        nargs=argparse.SUPPRESS,
        action=IgnoreAction,
    )

    parser.add_argument(
        flag,
        help=argparse.SUPPRESS,
        action="store_const",
        const=True,
    )
    parser.add_argument(
        f"--no-{base_flag}",
        help=argparse.SUPPRESS,
        dest=dest,
        action="store_const",
        const=False,
    )
    if hidden_true_flags:
        parser.add_argument(
            *hidden_true_flags,
            help=argparse.SUPPRESS,
            dest=dest,
            action="store_const",
            const=True,
        )


class DashPAction(Action):
    """
    Support for the tricky backwards compatibility game we're playing with the `-p` flag.
    It used to mean ``--party``, but now it means ``--port``.

    Note that Daml-LF defines ``PartyIdString`` as starting with a letter and NEVER with a number,
    so there is no possibility for ambiguity here.
    """

    def __call__(self, parser, namespace, values, option_string=None):
        try:
            port_value = int(values)
            parties_value = None
        except ValueError:
            port_value = None
            parties_value = values.split(",")

        if port_value is not None:
            namespace.port = port_value
        else:
            warnings.warn(
                "-p called with what appears to be a list of parties; use -u instead. "
                "This behavior will be unsupported in dazl v9",
                ConfigWarning,
            )
            existing_parties = getattr(namespace, "act_as", None)
            if existing_parties is None:
                existing_parties = []
                namespace.act_as = existing_parties
            existing_parties.extend(parties_value)


class AppendPartySetAction(Action):
    def __init__(self, option_strings: str, **kwargs):
        super().__init__(option_strings, metavar="PARTY", nargs="+", **kwargs)

    def __call__(self, parser, namespace, values, option_string=None):
        parties = getattr(namespace, self.dest, None)
        if parties is None:
            parties = []
            setattr(namespace, self.dest, parties)

        parties.extend(party for p in values for party in p.split(","))


class IgnoreAction(Action):
    def __init__(self, warning: Optional[str] = None, *args, **kwargs):
        self.warning = warning
        super().__init__(*args, **kwargs)

    def __call__(self, *args, **kwargs):
        if self.warning is not None:
            warnings.warn(self.warning, ConfigWarning)



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0


from argparse import ArgumentParser
from pathlib import Path
from typing import Sequence

from .. import Network
from ..client.config import AnonymousNetworkConfig, configure_parser
from ._base import CliCommand


class UploadCommand(CliCommand):
    name = "upload"

    def parser(self) -> ArgumentParser:
        arg_parser = ArgumentParser("dazl upload")

        configure_parser(arg_parser, config_file_support=True)
        arg_parser.add_argument(
            "files", metavar="FILE", nargs="+", help="DAR files to upload to the remote DAML ledger"
        )

        return arg_parser

    def execute(self, args) -> int:
        final_config = AnonymousNetworkConfig.get_config(args)

        contents = [Path(file).read_bytes() for file in args.files]

        network = Network()
        network.set_config(final_config)
        network.run_until_complete(upload_dars(network, contents))
        return 0


async def upload_dars(network, contents: Sequence[bytes]):
    for dar in contents:
        await network.aio_global().ensure_dar(dar)
